@@ -13,6 +13,8 @@ from glacier_rsync.file_cache import FileCache
 
 class BackupUtil:
 	def __init__(self, args):
+		self.continue_running = True
+
 		self.src = args.src
 		self.compress = args.compress
 		self.desc = args.desc
@@ -44,6 +46,20 @@ class BackupUtil:
 			cur.close()
 		logging.debug("init is done")
 
+	def stop(self):
+		"""
+		Set break condition for file list loop
+		Utility will exit as soon as current upload is complete.
+		"""
+		self.continue_running = False
+
+	def close(self):
+		"""
+		Close database connection
+		"""
+		self.conn.commit()
+		self.conn.close()
+
 	def backup(self):
 		"""
 		Interface function to find files and apply logic
@@ -58,10 +74,16 @@ class BackupUtil:
 
 		logging.info(f"number of files to backup: {len(file_list)}")
 		for file in file_list:
-			if not self._check_if_backed_up(file):  # True if already backed up
+			if not self.continue_running:
+				logging.info(f"Exiting early...")
+				break
+
+			is_backed_up, file_size, mtime = self._check_if_backed_up(file)
+			if not is_backed_up:  # True if already backed up
 				logging.info(f"{file} will be backed up")
 				file_object, compressed_file_object = self._compress(file)  # compress the file if specified
-				archive = self._backup(compressed_file_object)
+				desc = f'grsync|{file}|{file_size}|{mtime}|{self.desc}'
+				archive = self._backup(compressed_file_object, desc)
 				if archive is not None:
 					logging.info(f"{file} is backed up successfully")
 				else:
@@ -71,6 +93,7 @@ class BackupUtil:
 				self._mark_backed_up(file, archive)
 			else:
 				logging.info(f"{file} is already backed up, skipping...")
+		self.close()
 
 	def _check_if_backed_up(self, path):
 		"""
@@ -89,7 +112,7 @@ class BackupUtil:
 			sys.exit(3)
 		finally:
 			cur.close()
-		return len(rows) > 0
+		return len(rows) > 0, file_size, mtime
 
 	def _compress(self, file):
 		"""
@@ -147,16 +170,21 @@ class BackupUtil:
 			tree = parent
 		return tree[0]
 
-	def _backup(self, src_file_object):
+	def _backup(self, src_file_object, description):
 		"""
 		Send the file to glacier
 		:param src_file_object: FileCache object
+		:param description: Archive description including grsync meta
 		:return: archive information
 		"""
 		if src_file_object is None:  # only happens if unsupported compression algorithm
 			return None
 		try:
-			response = self.glacier.initiate_multipart_upload(vaultName=self.vault, partSize=str(self.part_size))
+			response = self.glacier.initiate_multipart_upload(
+				vaultName=self.vault,
+				partSize=str(self.part_size),
+				archiveDescription=description
+			)
 			upload_id = response['uploadId']
 
 			byte_pos = 0
